@@ -21,20 +21,22 @@
 #' result <- GCMeans(dataset,k = 5, m = 1.5, beta = 0.5, standardize = TRUE)
 GCMeans <- function(data, k, m, beta, maxiter = 500, tol = 0.01, standardize = TRUE, verbose = TRUE, init = "random", seed = NULL) {
 
-  data_class <- class(data)
+  #data_class <- class(data)
 
   if (verbose & standardize){
     print("Standardizing the data (set parameter to FALSE to avoid this step)")
   }
 
-  if(data_class == "list"){ # if we have to deal with a raster dataset
+  isRaster <- inherits(data,"list")
+
+  if(isRaster){ # if we have to deal with a raster dataset
     elements <- input_raster_data(dataset  = data,
                                   standardize = standardize)
     data <- elements$data
     missing <- elements$missing
     rst <- elements$rst
 
-  }else if(data_class == "data.frame"){ # if we have to deal with a dataframe
+  }else if(inherits(data,"data.frame")){ # if we have to deal with a dataframe
 
     # standardize data if required
     if (standardize) {
@@ -52,7 +54,7 @@ GCMeans <- function(data, k, m, beta, maxiter = 500, tol = 0.01, standardize = T
                          seed = seed, init = init)
 
   # if we are working with rasters, we should set some additional values
-  if(data_class == "list"){
+  if(isRaster){
     results <- output_raster_data(results, missing, rst)
   }
 
@@ -110,10 +112,10 @@ SGFCMeans <- function(data, nblistw = NULL, k, m, alpha, beta, lag_method="mean"
                       maxiter = 500, tol = 0.01,
                       standardize = TRUE, verbose = TRUE, init = "random", seed = NULL) {
 
-  data_class <- class(data)
+  isRaster <- inherits(data, "list")
 
-  if(data_class != "list"){
-    if(class(nblistw)[[1]] != "listw"){
+  if(isRaster==FALSE){
+    if(inherits(nblistw, "listw")==FALSE){
       stop("the nblistw must be a listw object from spdep package")
     }
     if(lag_method %in% c("mean","median") == FALSE){
@@ -123,7 +125,7 @@ SGFCMeans <- function(data, nblistw = NULL, k, m, alpha, beta, lag_method="mean"
 
 
 
-  if(data_class == "list"){ # if we have to deal with a raster dataset
+  if(isRaster){ # if we have to deal with a raster dataset
     elements <- input_raster_data(data,
                                   w = window,
                                   fun = lag_method,
@@ -134,7 +136,7 @@ SGFCMeans <- function(data, nblistw = NULL, k, m, alpha, beta, lag_method="mean"
     missing <- elements$missing
     rst <- elements$rst
 
-  }else if(data_class == "data.frame"){ # if we have to deal with a dataframe
+  }else if(inherits(data,"data.frame")){ # if we have to deal with a dataframe
 
     # standardize data if required
     if (standardize) {
@@ -155,7 +157,7 @@ SGFCMeans <- function(data, nblistw = NULL, k, m, alpha, beta, lag_method="mean"
                          seed = seed, init = init)
 
   # if we are working with rasters, we should set some additional values
-  if(data_class == "list"){
+  if(isRaster){
     results <- output_raster_data(results, missing, rst)
     results$window <- window
   }
