@@ -7,66 +7,65 @@ using namespace Rcpp;
 //%%%%%%%%%%%%%%%%%%%%%% MORAN RELATED FUNCTIONS %%%%%%%%%%%%%%%%%%%%%%%%%%%%
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
-//' @title Moran I calculated on a matrix
-//' @name moranI_matrix
-//' @param mat a matrix
-//' @param w the size of the neighbouring window
-//' @return a double, the value of Moran I
-//' @keywords internal
-//' @export
-//'
-// [[Rcpp::export]]
-double moranI_matrix(NumericMatrix mat, int w){
-  double xbar = mean(na_omit(mat));
-  //float weight = 1/pow(w*2+1,2);
-  float weight = 1.0;
-  int nr = mat.nrow();
-  int nc = mat.ncol();
-  int r,c,lr,hr,lc,hc;
-  double num = 0.0;
-  double denom = 0.0;
-  double denom2 = 0.0;
-  int N = 0;
-  int wr,wc;
-  NumericMatrix submat, prod;
-  for (r = 0; r < mat.nrow() ; r++){
-    wr = w;
-    lr = r - w;
-    hr = r + w;
-    if(lr < 0){
-      wr = w + lr;
-      lr = 0;
-    }
-    if(hr >= nr){
-      hr = nr-1;
-    }
-    for(c = 0; c < mat.ncol(); c++){
-      wc = w;
-      lc = c - w;
-      hc = c + w;
-      if(lc < 0){
-        wc = w + lc;
-        lc = 0;
-      }
-      if(hc >= nc){
-        hc = nc-1;
-      }
-      float xi =  mat(r,c);
-      if(!Rcpp::traits::is_nan<REALSXP>(xi)){
-        N++;
-        denom = denom + pow((xi - xbar),2);
-        submat = mat(Range(lr,hr),Range(lc,hc));
-        submat(wr,wc) = NA_REAL;
-        prod = (submat - xbar) * (xi - xbar) * weight;
-        num = num + sum(na_omit(prod));
-        denom2 = denom2 + ((submat.ncol() * submat.nrow() -1)* weight);
-
-        }
-      }
-    }
-  double MoranI = (N / denom2) * (num/denom);
-  return MoranI;
-}
+// @title Moran I calculated on a matrix
+// @name moranI_matrix
+// @param mat a matrix
+// @param w the size of the neighbouring window
+// @return a double, the value of Moran I
+// @keywords internal
+// @export
+//
+// double moranI_matrix(NumericMatrix mat, int w){
+//   double xbar = mean(na_omit(mat));
+//   //float weight = 1/pow(w*2+1,2);
+//   float weight = 1.0;
+//   int nr = mat.nrow();
+//   int nc = mat.ncol();
+//   int r,c,lr,hr,lc,hc;
+//   double num = 0.0;
+//   double denom = 0.0;
+//   double denom2 = 0.0;
+//   int N = 0;
+//   int wr,wc;
+//   NumericMatrix submat, prod;
+//   for (r = 0; r < mat.nrow() ; r++){
+//     wr = w;
+//     lr = r - w;
+//     hr = r + w;
+//     if(lr < 0){
+//       wr = w + lr;
+//       lr = 0;
+//     }
+//     if(hr >= nr){
+//       hr = nr-1;
+//     }
+//     for(c = 0; c < mat.ncol(); c++){
+//       wc = w;
+//       lc = c - w;
+//       hc = c + w;
+//       if(lc < 0){
+//         wc = w + lc;
+//         lc = 0;
+//       }
+//       if(hc >= nc){
+//         hc = nc-1;
+//       }
+//       float xi =  mat(r,c);
+//       if(!Rcpp::traits::is_nan<REALSXP>(xi)){
+//         N++;
+//         denom = denom + pow((xi - xbar),2);
+//         submat = mat(Range(lr,hr),Range(lc,hc));
+//         submat(wr,wc) = NA_REAL;
+//         prod = (submat - xbar) * (xi - xbar) * weight;
+//         num = num + sum(na_omit(prod));
+//         denom2 = denom2 + ((submat.ncol() * submat.nrow() -1)* weight);
+//
+//         }
+//       }
+//     }
+//   double MoranI = (N / denom2) * (num/denom);
+//   return MoranI;
+// }
 
 
 //' @title Moran I calculated on a matrix with a given window
@@ -237,98 +236,97 @@ NumericVector local_moranI_matrix_window(NumericMatrix mat, NumericMatrix window
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 
-//' @title Elsa statistic calculated on a matrix
-//' @name Elsa_categorical_matrix
-//' @description method described here : https://doi.org/10.1016/j.spasta.2018.10.001
-//' @param mat an IntegerMatrix, must be filled with integer, -1 indicates NA values, categories must start at 0
-//' @param w the size of the neighbouring window
-//' @param dist a distance matrix between the categories
-//' @return a NumericVector : the local values of ELSA
-//' @keywords internal
-//' @export
-//'
-// [[Rcpp::export]]
-NumericVector Elsa_categorical_matrix(IntegerMatrix mat, int w, NumericMatrix dist){
-  int m = dist.nrow();
-  int nr = mat.nrow();
-  int nc = mat.ncol();
-  int r,c,lr,hr,lc,hc,i,j,xi,xj,nn;
-  int N = 0;
-  int wr,wc;
-  double d = max_mat(dist);
-  int counter = 0;
-  double Ea,Ec,pk;
-  NumericVector elsa(mat.nrow()*mat.ncol());
-  IntegerMatrix submat;
-  for (r = 0; r < mat.nrow() ; r++){
-    wr = w;
-    lr = r - w;
-    hr = r + w;
-    if(lr < 0){
-      wr = w + lr;
-      lr = 0;
-    }
-    if(hr >= nr){
-      hr = nr-1;
-    }
-    for(c = 0; c < mat.ncol(); c++){
-      wc = w;
-      lc = c - w;
-      hc = c + w;
-      if(lc < 0){
-        wc = w + lc;
-        lc = 0;
-      }
-      if(hc >= nc){
-        hc = nc-1;
-      }
-      xi =  mat(r,c);
-      if(xi >= 0){
-        Ea = 0;
-        N++;
-        submat = mat(Range(lr,hr),Range(lc,hc));
-        nn = (submat.ncol()*submat.nrow() - 1);
-
-        // now I want to calculate Eci
-        Ec = 0;
-        for(i = 0; i < m; i++){
-          pk = float(sum(submat == i)) / float(nn+1.0);
-          if(pk > 0){
-            Ec = Ec + pk * log2(pk);
-          }
-        }
-
-        if(nn > m){
-          Ec = Ec / log2(float(m));
-        }else{
-          Ec = Ec / log2(float(nn));
-        }
-
-        // now I want to calculate Eai
-        submat(wr,wc) = -1;
-        //here I want to iterate over the neighbours to calculate the sum of their differences
-        //based on the values in dist
-        for(i = 0; i < submat.nrow(); i++){
-          for(j = 0; j < submat.ncol(); j++) {
-            xj = submat(i,j);
-            if(xj >=0 ){
-              Ea = Ea + dist(xi,xj);
-            }
-          }
-        }
-        Ea = Ea / (d * float(nn));
-        elsa(counter) = (-1.0*Ec) * Ea;
-
-      }else{
-      // IF XI is NA
-      elsa(counter) = -1;
-      }
-      counter++;
-    }
-  }
-  return elsa;
-
-}
+// @title Elsa statistic calculated on a matrix
+// @name Elsa_categorical_matrix
+// @description method described here : https://doi.org/10.1016/j.spasta.2018.10.001
+// @param mat an IntegerMatrix, must be filled with integer, -1 indicates NA values, categories must start at 0
+// @param w the size of the neighbouring window
+// @param dist a distance matrix between the categories
+// @return a NumericVector : the local values of ELSA
+// @keywords internal
+// @export
+//
+// NumericVector Elsa_categorical_matrix(IntegerMatrix mat, int w, NumericMatrix dist){
+//   int m = dist.nrow();
+//   int nr = mat.nrow();
+//   int nc = mat.ncol();
+//   int r,c,lr,hr,lc,hc,i,j,xi,xj,nn;
+//   int N = 0;
+//   int wr,wc;
+//   double d = max_mat(dist);
+//   int counter = 0;
+//   double Ea,Ec,pk;
+//   NumericVector elsa(mat.nrow()*mat.ncol());
+//   IntegerMatrix submat;
+//   for (r = 0; r < mat.nrow() ; r++){
+//     wr = w;
+//     lr = r - w;
+//     hr = r + w;
+//     if(lr < 0){
+//       wr = w + lr;
+//       lr = 0;
+//     }
+//     if(hr >= nr){
+//       hr = nr-1;
+//     }
+//     for(c = 0; c < mat.ncol(); c++){
+//       wc = w;
+//       lc = c - w;
+//       hc = c + w;
+//       if(lc < 0){
+//         wc = w + lc;
+//         lc = 0;
+//       }
+//       if(hc >= nc){
+//         hc = nc-1;
+//       }
+//       xi =  mat(r,c);
+//       if(xi >= 0){
+//         Ea = 0;
+//         N++;
+//         submat = mat(Range(lr,hr),Range(lc,hc));
+//         nn = (submat.ncol()*submat.nrow() - 1);
+//
+//         // now I want to calculate Eci
+//         Ec = 0;
+//         for(i = 0; i < m; i++){
+//           pk = float(sum(submat == i)) / float(nn+1.0);
+//           if(pk > 0){
+//             Ec = Ec + pk * log2(pk);
+//           }
+//         }
+//
+//         if(nn > m){
+//           Ec = Ec / log2(float(m));
+//         }else{
+//           Ec = Ec / log2(float(nn));
+//         }
+//
+//         // now I want to calculate Eai
+//         submat(wr,wc) = -1;
+//         //here I want to iterate over the neighbours to calculate the sum of their differences
+//         //based on the values in dist
+//         for(i = 0; i < submat.nrow(); i++){
+//           for(j = 0; j < submat.ncol(); j++) {
+//             xj = submat(i,j);
+//             if(xj >=0 ){
+//               Ea = Ea + dist(xi,xj);
+//             }
+//           }
+//         }
+//         Ea = Ea / (d * float(nn));
+//         elsa(counter) = (-1.0*Ec) * Ea;
+//
+//       }else{
+//       // IF XI is NA
+//       elsa(counter) = -1;
+//       }
+//       counter++;
+//     }
+//   }
+//   return elsa;
+//
+// }
 
 
 
